<?php
//Photo Contest Facebook APP
//Created and Copyright Zbynek Hovorka
//Official FB page - https://www.facebook.com/pages/Photo-Contest-FB-App/457225521028147
//Special Thanks - Josef Kuchar

require_once 'dibi/dibi.php';

class myDb
{
	private $ini_array = array();

	public function __construct()
	{
		$ini_array = parse_ini_file("config.ini", true);
		dibi::connect($ini_array['database']
			);

	}
	public function getVotedUsersByPhotoId($id)
{
 return dibi::query('SELECT * FROM [rating] INNER JOIN [users] ON [rating].[user_id] = [users].[id] WHERE [rating].[photo_id] = %i', $id)
   ->fetchAll();
 
}

	public function getUser($id)
	{
		return dibi::select('*')
				->from('users')
				->where('id = %i', $id)
				->fetchAll();
	}
	public function getUsers()
	{
		return dibi::select('*')
				->from('users')
				->orderBy('username asc')
				->fetchAll();
	}
		public function getUsersWithToken()
	{
		return dibi::select('*')
				->from('users')
				->where('token <> ""')
				->orderBy('username asc')
				->fetchAll();
	}

	public function setUser(array $user)
	{
		return dibi::query('INSERT INTO [users]', $user);
	}

	public function getExtendedUser($user_id)
	{
		return dibi::select('extended')
				->from('users')
				->where('id = %i', $user_id)
				->fetchSingle();
	}
	public function setExtendedUser($user_id)
	{
		return dibi::query('UPDATE [users] SET extended = 1 WHERE id = %i', $user_id);
	}

	/*
	 * select by user_id
	 */
	public function getPhoto($id)
	{
		return dibi::select('*')
			->from('photos')
			->where('user_id = %i', $id)
			->fetchAll();
	}

	public function getPhotosId()
	{
		return dibi::select('id')
		->from('photos')
		->fetchAll();
	}


	public function getPhotoByID($id)
	{
		return dibi::select('*')
		->from('photos')
		->innerJoin('users')
		->on('users.id = photos.user_id')
		->where('photos.id = %i', $id)
		->fetchAll();
	}
	public function getPhotoBeforeID($id)
	{
		return dibi::select('photos.id')
		->from('photos')
		->where('photos.id < %i', $id)
		->where('display = 1')
		->orderBy('photos.id desc')
		->fetchSingle();
	}

		public function getPhotoAfterID($id)
	{
		return dibi::select('photos.id')
		->from('photos')
		->where('photos.id > %i', $id)
		->where('display = 1')
		->orderBy('photos.id asc')
		->fetchSingle();
	}


		public function getPhotoLastID($id)
	{
		return dibi::select('photos.id')
		->from('photos')
		->where('display = 1')
		->orderBy('photos.id DESC')
		->fetchSingle();
	}
		public function getPhotoFirstID($id)
	{
		return dibi::select('photos.id')
		->from('photos')
		->where('display = 1')
		->orderBy('photos.id ASC')
		->fetchSingle();
	}

	public function getPhotoByUser($id)
	{
		return dibi::select('*, photos.id as pid')
		->from('photos')
		->innerJoin('users')
		->on('users.id = photos.user_id')
		->where('photos.user_id = %i', $id)
		->fetchAll();
	}

	public function insertPhoto(array $args)
	{
		dibi::query('UPDATE [users] SET photo_count = photo_count + 1 WHERE id = %i', $args['user_id']);
		return dibi::query('INSERT INTO [photos]', $args);
	}
	public function updatePhoto($id, array $args)
	{
		return dibi::query('UPDATE [photos] SET', $args, 'WHERE id = %i', $id);
	}
	public function updatePhotoRating($id)
	{
		return dibi::query('UPDATE [photos] SET rating = rating + 1 WHERE id = %i', $id);
	}

	public function getGallery($orderBy = 'photos.id DESC', $ofsset = 0, $limit = 14)
	{
		return dibi::select('*, photos.id as pid')
			->from('photos')
			->innerJoin('users')
			->on('users.id = photos.user_id')
			->orderBy($orderBy)
			->fetchAll($ofsset, $limit);
	}
	public function getGalleryFront($orderBy = 'photos.id DESC', $ofsset = 0, $limit = 14)
	{
		return dibi::select('*, photos.id as pid')
			->from('photos')
			->where('display = 1')
			->innerJoin('users')
			->on('users.id = photos.user_id')
			->orderBy($orderBy)
			->fetchAll($ofsset, $limit);
	}


	public function countImagesGallery()
	{
		return dibi::select('*')
			->from('photos')
			->where('display = 1')
			->count();
	}
	public function countImages()
	{
		return dibi::select('*')
			->from('photos')
			->count();
	}

	public function selectRating($photo_id, $user_id)
	{
		return dibi::select('*')
			->from('rating')
			->where('user_id = %i AND photo_id = %i', $user_id, $photo_id)
			->count();
	}

	public function saveRating($photo_id, $user_id)
	{
		if(dibi::query('INSERT INTO [rating]', array('user_id' => $user_id, 'photo_id' => $photo_id)))
		{
			return dibi::query('UPDATE [photos] SET rating = rating + 1 WHERE `id`=%i', $photo_id);
		}
	}

	public function getRules()
	{
		return dibi::select('condition')
			->from('settings')
			->fetchAll();
	}
	public function getFaq()
	{
		return dibi::select('faq')
			->from('settings')
			->fetchAll();
	}
	public function getTracking()
	{
		return dibi::select('tracking')
			->from('settings')
			->fetchAll();
	}
	public function getPrivacy()
	{
		return dibi::select('privacy')
			->from('settings')
			->fetchAll();
	}

	public function getPoradatel()
	{
		return dibi::select('url')
			->from('settings')
			->fetchAll();
	}

		public function getCount()
	{
		return dibi::select('count')
			->from('settings')
			->fetchAll();
	}
			public function getImgPerPage()
	{
		return dibi::select('img_per_page')
			->from('settings')
			->fetchAll();
	}

	public function getEvent()
	{
		return dibi::select('event')
			->from('settings')
			->fetchAll();
	}

	public function getOrganizer()
	{
		return dibi::select('*')
			->from('organizer')
			->fetchAll();
	}


	/*
	 * Admin
	 */

	public function login($user, $pass)
	{
		return dibi::select('*')
			->from('admin')
			->where('user = %s AND pass = %s', $user, $pass)
			->count();
	}

	public function countRating()
	{
		return dibi::select('*')
			->from('rating')
			->count();
	}

	public function updateCustompage($args)
	{
		return dibi::update('custompage', $args)
			->execute();
	}
	public function updateSettings($args)
	{
		return dibi::update('settings', $args)
			->execute();
	}
	public function getSettings()
	{
		return dibi::select('*')
			->from('settings')
			->fetchAll();
	}
	public function getCustompage()
	{
		return dibi::select('*')
			->from('custompage')
			->fetchAll();
	}
		public function getRights()
	{
		return dibi::select('*')
			->from('rights')
			->fetch();
	}
		public function updateRights($args)
	{
		return dibi::update('rights', $args)
			->execute();
	}

	public function deleteImage($id)
	{
		dibi::delete('rating')
			->where('photo_id = %i', $id)
			->execute();
		return dibi::delete('photos')
			->where('id = %i', $id)
			->execute();
	}

	public function searchGallery($search)
	{
		return dibi::select('*, photos.id as pid')
			->from('photos')
			->innerJoin('users')
			->on('users.id = photos.user_id')
			->where('photos.photo_name')
      ->like('%~like~',$search)
			->fetchAll();
	}

	public function getUserByName($name)
	{
		return dibi::select('id')
			->from('users')
			->where('username = %s', $name)
			->fetchAll();
	}

	public function searchGalleryByUser($id)
	{
		return dibi::select('*, photos.id as pid')
			->from('photos')
			->innerJoin('users')
			->on('users.id = photos.user_id')
			->where('photos.user_id = %i', $id)
			->fetchAll();
	}



}
